==> cpp-opentelemetry-sdk-1.3.0-h3060df4_1.tar.bz2: Library/lib/cmake/opentelemetry-cpp/opentelemetry-cpp-target-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "opentelemetry-cpp::proto" for configuration "Release"
set_property(TARGET opentelemetry-cpp::proto APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::proto PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_proto.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::proto )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::proto "${_IMPORT_PREFIX}/lib/opentelemetry_proto.lib" )

# Import target "opentelemetry-cpp::common" for configuration "Release"
set_property(TARGET opentelemetry-cpp::common APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::common PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_common.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::common )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::common "${_IMPORT_PREFIX}/lib/opentelemetry_common.lib" )

# Import target "opentelemetry-cpp::trace" for configuration "Release"
set_property(TARGET opentelemetry-cpp::trace APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::trace PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_trace.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::trace )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::trace "${_IMPORT_PREFIX}/lib/opentelemetry_trace.lib" )

# Import target "opentelemetry-cpp::metrics" for configuration "Release"
set_property(TARGET opentelemetry-cpp::metrics APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::metrics PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_metrics.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::metrics )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::metrics "${_IMPORT_PREFIX}/lib/opentelemetry_metrics.lib" )

# Import target "opentelemetry-cpp::version" for configuration "Release"
set_property(TARGET opentelemetry-cpp::version APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::version PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_version.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::version )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::version "${_IMPORT_PREFIX}/lib/opentelemetry_version.lib" )

# Import target "opentelemetry-cpp::resources" for configuration "Release"
set_property(TARGET opentelemetry-cpp::resources APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::resources PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_resources.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::resources )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::resources "${_IMPORT_PREFIX}/lib/opentelemetry_resources.lib" )

# Import target "opentelemetry-cpp::http_client_curl" for configuration "Release"
set_property(TARGET opentelemetry-cpp::http_client_curl APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::http_client_curl PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_http_client_curl.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::http_client_curl )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::http_client_curl "${_IMPORT_PREFIX}/lib/opentelemetry_http_client_curl.lib" )

# Import target "opentelemetry-cpp::otlp_recordable" for configuration "Release"
set_property(TARGET opentelemetry-cpp::otlp_recordable APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::otlp_recordable PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_otlp_recordable.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::otlp_recordable )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::otlp_recordable "${_IMPORT_PREFIX}/lib/opentelemetry_otlp_recordable.lib" )

# Import target "opentelemetry-cpp::otlp_grpc_exporter" for configuration "Release"
set_property(TARGET opentelemetry-cpp::otlp_grpc_exporter APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::otlp_grpc_exporter PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_otlp_grpc.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::otlp_grpc_exporter )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::otlp_grpc_exporter "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_otlp_grpc.lib" )

# Import target "opentelemetry-cpp::otlp_grpc_log_exporter" for configuration "Release"
set_property(TARGET opentelemetry-cpp::otlp_grpc_log_exporter APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::otlp_grpc_log_exporter PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_otlp_grpc_log.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::otlp_grpc_log_exporter )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::otlp_grpc_log_exporter "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_otlp_grpc_log.lib" )

# Import target "opentelemetry-cpp::otlp_http_client" for configuration "Release"
set_property(TARGET opentelemetry-cpp::otlp_http_client APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::otlp_http_client PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_otlp_http_client.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::otlp_http_client )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::otlp_http_client "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_otlp_http_client.lib" )

# Import target "opentelemetry-cpp::otlp_http_exporter" for configuration "Release"
set_property(TARGET opentelemetry-cpp::otlp_http_exporter APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::otlp_http_exporter PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_otlp_http.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::otlp_http_exporter )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::otlp_http_exporter "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_otlp_http.lib" )

# Import target "opentelemetry-cpp::ostream_span_exporter" for configuration "Release"
set_property(TARGET opentelemetry-cpp::ostream_span_exporter APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::ostream_span_exporter PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_ostream_span.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::ostream_span_exporter )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::ostream_span_exporter "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_ostream_span.lib" )

# Import target "opentelemetry-cpp::opentelemetry_exporter_zipkin_trace" for configuration "Release"
set_property(TARGET opentelemetry-cpp::opentelemetry_exporter_zipkin_trace APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::opentelemetry_exporter_zipkin_trace PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_zipkin_trace.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::opentelemetry_exporter_zipkin_trace )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::opentelemetry_exporter_zipkin_trace "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_zipkin_trace.lib" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> cpp-opentelemetry-sdk-1.4.1-h3060df4_1.tar.bz2: Library/lib/cmake/opentelemetry-cpp/opentelemetry-cpp-target-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "opentelemetry-cpp::proto" for configuration "Release"
set_property(TARGET opentelemetry-cpp::proto APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::proto PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_proto.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::proto )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::proto "${_IMPORT_PREFIX}/lib/opentelemetry_proto.lib" )

# Import target "opentelemetry-cpp::common" for configuration "Release"
set_property(TARGET opentelemetry-cpp::common APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::common PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_common.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::common )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::common "${_IMPORT_PREFIX}/lib/opentelemetry_common.lib" )

# Import target "opentelemetry-cpp::trace" for configuration "Release"
set_property(TARGET opentelemetry-cpp::trace APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::trace PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_trace.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::trace )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::trace "${_IMPORT_PREFIX}/lib/opentelemetry_trace.lib" )

# Import target "opentelemetry-cpp::metrics" for configuration "Release"
set_property(TARGET opentelemetry-cpp::metrics APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::metrics PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_metrics.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::metrics )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::metrics "${_IMPORT_PREFIX}/lib/opentelemetry_metrics.lib" )

# Import target "opentelemetry-cpp::version" for configuration "Release"
set_property(TARGET opentelemetry-cpp::version APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::version PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_version.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::version )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::version "${_IMPORT_PREFIX}/lib/opentelemetry_version.lib" )

# Import target "opentelemetry-cpp::resources" for configuration "Release"
set_property(TARGET opentelemetry-cpp::resources APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::resources PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_resources.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::resources )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::resources "${_IMPORT_PREFIX}/lib/opentelemetry_resources.lib" )

# Import target "opentelemetry-cpp::http_client_curl" for configuration "Release"
set_property(TARGET opentelemetry-cpp::http_client_curl APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::http_client_curl PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_http_client_curl.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::http_client_curl )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::http_client_curl "${_IMPORT_PREFIX}/lib/opentelemetry_http_client_curl.lib" )

# Import target "opentelemetry-cpp::otlp_recordable" for configuration "Release"
set_property(TARGET opentelemetry-cpp::otlp_recordable APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::otlp_recordable PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_otlp_recordable.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::otlp_recordable )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::otlp_recordable "${_IMPORT_PREFIX}/lib/opentelemetry_otlp_recordable.lib" )

# Import target "opentelemetry-cpp::otlp_grpc_exporter" for configuration "Release"
set_property(TARGET opentelemetry-cpp::otlp_grpc_exporter APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::otlp_grpc_exporter PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_otlp_grpc.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::otlp_grpc_exporter )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::otlp_grpc_exporter "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_otlp_grpc.lib" )

# Import target "opentelemetry-cpp::otlp_grpc_log_exporter" for configuration "Release"
set_property(TARGET opentelemetry-cpp::otlp_grpc_log_exporter APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::otlp_grpc_log_exporter PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_otlp_grpc_log.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::otlp_grpc_log_exporter )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::otlp_grpc_log_exporter "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_otlp_grpc_log.lib" )

# Import target "opentelemetry-cpp::otlp_http_client" for configuration "Release"
set_property(TARGET opentelemetry-cpp::otlp_http_client APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::otlp_http_client PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_otlp_http_client.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::otlp_http_client )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::otlp_http_client "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_otlp_http_client.lib" )

# Import target "opentelemetry-cpp::otlp_http_exporter" for configuration "Release"
set_property(TARGET opentelemetry-cpp::otlp_http_exporter APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::otlp_http_exporter PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_otlp_http.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::otlp_http_exporter )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::otlp_http_exporter "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_otlp_http.lib" )

# Import target "opentelemetry-cpp::ostream_span_exporter" for configuration "Release"
set_property(TARGET opentelemetry-cpp::ostream_span_exporter APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::ostream_span_exporter PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_ostream_span.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::ostream_span_exporter )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::ostream_span_exporter "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_ostream_span.lib" )

# Import target "opentelemetry-cpp::ostream_metrics_exporter" for configuration "Release"
set_property(TARGET opentelemetry-cpp::ostream_metrics_exporter APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::ostream_metrics_exporter PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_ostream_metrics.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::ostream_metrics_exporter )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::ostream_metrics_exporter "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_ostream_metrics.lib" )

# Import target "opentelemetry-cpp::opentelemetry_exporter_zipkin_trace" for configuration "Release"
set_property(TARGET opentelemetry-cpp::opentelemetry_exporter_zipkin_trace APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(opentelemetry-cpp::opentelemetry_exporter_zipkin_trace PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_zipkin_trace.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS opentelemetry-cpp::opentelemetry_exporter_zipkin_trace )
list(APPEND _IMPORT_CHECK_FILES_FOR_opentelemetry-cpp::opentelemetry_exporter_zipkin_trace "${_IMPORT_PREFIX}/lib/opentelemetry_exporter_zipkin_trace.lib" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
